"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const inquirer_1 = __importDefault(require("../../utils/inquirer"));
const questions_1 = require("./questions");
const console_1 = require("../../utils/console");
exports.isSetupComplete = () => !!(process.env.PIVOTAL_TOKEN && process.env.PIVOTAL_PROJECT_ID);
/**
 * Displays the instructions based on user's answers.
 * @param {SetupAnswers} answers - Setup prompt answers
 */
const displaySetupInstructions = ({ pivotalToken, pivotalProjectId }) => console_1.log(chalk_1.default `
To get started with pivotal-flow, run the following commands in your current terminal session:-

  {bold export PIVOTAL_TOKEN=${pivotalToken}}
  {bold export PIVOTAL_PROJECT_ID=${pivotalProjectId}}

{dim.italic You can also add them to your profile (~/.bash_profile, ~/.zshrc, ~/.profile, or ~/.bashrc) so the environment variables are automatically added for all new terminal sessions.}
`);
/**
 * Collects user input & displays setup instructions accordingly.
 */
exports.performSetup = () => __awaiter(void 0, void 0, void 0, function* () {
    const answers = yield inquirer_1.default.prompt(questions_1.SetupQuestions);
    const { pivotalProjectId, pivotalToken } = answers;
    if (pivotalProjectId && pivotalToken) {
        displaySetupInstructions(answers);
    }
    else {
        console_1.error('Failed to set-up pivotal-flow. Please try again.');
    }
});
/**
 * Aborts if pivotal-flow has not been set-up. Displays setup instructions before aborting.
 */
exports.abortIfNotSetup = () => __awaiter(void 0, void 0, void 0, function* () {
    if (!exports.isSetupComplete()) {
        const { wantSetup } = yield inquirer_1.default.prompt(questions_1.PromptToSetup);
        if (wantSetup) {
            yield exports.performSetup();
        }
        else {
            console_1.error(`Setup for pivotal-flow incomplete. Please try again after running 'pivotal-flow init'.`);
        }
        // return non-zero error code when set-up is not completed.
        process.exit(wantSetup ? 0 : 1);
    }
    else {
        return;
    }
});
